from distutils.core import setup

import pioc
 
setup(name = 'pioc',
      version = '1.0.0',
      description = 'python ioc',
      long_description = '',
      author = 'xwann',
      author_email = '1220936030@qq.com',
      url = '',
      py_modules=['pioc'],
      scripts=['pioc.py'],
      license = '',
      platforms='any',
      classifiers = [
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
      ]
)